@@ -230,7 +230,7 @@ class AwesomeHTMLTranslator(HTML5Translator):
             # for docutils >0.17
             node.html5tagname = "div"
             self.body.append('<div class="highlight" data-controller="code">\n')
-            lang = node.get("language")
+            lang = node.get("language", "")
             code_header = "<div class='code-header'>\n"
             code_header += (
                 f"<span class='code-lang'>{lang.replace('default', 'python')}</span>\n"
@@ -273,7 +273,6 @@ def setup(app: "Sphinx") -> Dict[str, Any]:
     """
     app.set_translator("html", AwesomeHTMLTranslator)
     app.set_translator("dirhtml", AwesomeHTMLTranslator)
-    app.add_config_value("html_collapsible_definitions", False, "html")
 
     return {
         "version": __version__,
